pub struct WfpSublayer;Expand description
WFP Sublayer for windows-wfp filters
All windows-wfp filters are added to this sublayer, allowing them to be managed as a group and ensuring proper priority.
Implementations
Sourceimpl WfpSublayer
impl WfpSublayer
Sourcepub fn register(engine: &WfpEngine) -> WfpResult<()>
pub fn register(engine: &WfpEngine) -> WfpResult<()>
Register windows-wfp sublayer
The sublayer groups all windows-wfp filters together and assigns them a specific weight for priority ordering.
Errors
Returns WfpError::Other if sublayer registration fails.
Examples
use windows_wfp::{WfpEngine, WfpProvider, WfpSublayer};
let engine = WfpEngine::new()?;
WfpProvider::register(&engine)?;
WfpSublayer::register(&engine)?;Auto Trait Implementations
impl Freeze for WfpSublayer
impl RefUnwindSafe for WfpSublayer
impl Send for WfpSublayer
impl Sync for WfpSublayer
impl Unpin for WfpSublayer
impl UnsafeUnpin for WfpSublayer
impl UnwindSafe for WfpSublayer